#!/bin/bash
#

# build_six.sh  <product_directory> <qual> [tar]

usage()
{
   echo "USAGE: `basename ${0}` <product_directory> <p2711 | p2713d > [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
pqual=${2}
maketar=${3}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

if [[ -z "${pqual}" ]] || [[ "${pqual}" == "tar" ]]
then
  echo "Python qualifier is mandatory." 1>&2
  usage
  exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=six
origpkgver=v1_10_0
pkgver=${origpkgver}d
ssibuildshims_version=v0_17_00
pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`
pkgtarname=${package}-${pkgdotver}
make_tarball_opts=(-d bin:lib:man -F "${product_dir}" "${package}" "${pkgver}" "${pqual}" NO_FLAVOR)
get_this_dir
get_ssibuildshims

basequal=$pqual # Required by define_basics
source define_basics NO_TYPE NO_FQ_DIR

if [ "${maketar}" = "tar" ] && [ -f "${pkgdir}.version/NULL_${pqual}" ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball "${make_tarball_opts[@]}"
   exit 0
fi

echo "building ${package} for ${OS}-${plat}"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

mkdir -p ${blddir} 
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi

if [ ${OS1} = "Darwin" ]
then
   PATH=`dropit /usr/bin/get-cert $PATH`
fi

# declare now so we can setup
# fake ups declare
fakedb=${product_dir}/${package}/${pkgver}/fakedb
${SSIBUILDSHIMS_DIR}/bin/fake_declare_product ${product_dir} ${package} ${pkgver} ${pqual} NO_FLAVOR

# setup
setup -B ${package} ${pkgver} -q ${pqual} -z ${fakedb}:${product_dir}:${PRODUCTS} || ssi_die "fake setup failed"

set -x

# work in a build directory, which will not be part of any distribution
cd ${blddir} || ssi_die "Unable to cd into ${blddir}"

# Python short version for use in paths.
python_shortdotversion=${PYTHON_VERSION#v}
python_shortdotversion=${python_shortdotversion//_/.}
python_shortdotversion=${python_shortdotversion%.*}

mkdir -p ${pkgdir}/lib/python${python_shortdotversion}/site-packages || \
  ssi_die "failed to create ${pkgdir}/lib/python2.7/site-packages"

tar xf ${tardir}/${pkgtarname}.tar.gz || ssi_die "Failed to untar ${pkgtarname}.tar.gz"
cd ${package}-${pkgdotver} || ssi_die "Failed to cd into ${package}-${pkgdotver}"
python setup.py install --prefix ${pkgdir} || ssi_die "python setup.py install failed"

set +x

if [ ! -d ${pkgdir}/lib ]
then
   echo "ERROR: failed to create ${pkgdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# real ups declare
${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} ${pqual} NO_FLAVOR || ssi_die "failed to declare ${package} ${pkgver}"

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup -B ${package} ${pkgver} -q ${pqual} -z ${product_dir}
echo "six is installed at ${SIX_DIR}"

# this must be last
if [ "${maketar}" = "tar" ]  && [ -f "${pkgdir}.version/NULL_${pqual}" ]
then
  ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball "${make_tarball_opts[@]}"
fi

exit 0
